==> iTop-3.0.3-10998.zip: web/datamodels/2.x/itop-core-update/module.itop-core-update.php <==
<?php
/**
 * Copyright (C) 2013-2021 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */

//
// iTop module definition file
//

/** @noinspection PhpUnhandledExceptionInspection */
SetupWebPage::AddModule(
	__FILE__, // Path to the current file, all other file names are relative to the directory containing this file
	'itop-core-update/3.0.3',
	array(
		// Identification
		//
		'label' => 'iTop Core Update',
		'category' => 'business',

		// Setup
		//
		'dependencies' => array(
            'itop-files-information/2.7.0',
            'combodo-db-tools/2.7.0',
		),
		'mandatory' => false,
		'visible' => true,

		// Components
		//
		'datamodel' => array(
			'model.itop-core-update.php',
			'src/Service/RunTimeEnvironmentCoreUpdater.php',
			'src/Service/CoreUpdater.php',
			'src/Controller/UpdateController.php',
			'src/Controller/AjaxController.php',
		),
		'webservice' => array(),
		'data.struct' => array(),
		'data.sample' => array(),

		// Documentation
		//
		'doc.manual_setup' => '', // hyperlink to manual setup documentation, if any
		'doc.more_information' => '', // hyperlink to more information, if any

		// Default settings
		//
		'settings' => array(),
	)
);

==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-core-update/module.itop-core-update.php <==
<?php
/**
 * Copyright (C) 2013-2023 Combodo SARL
 *
 * This file is part of iTop.
 *
 * iTop is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * iTop is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 */

//
// iTop module definition file
//

/** @noinspection PhpUnhandledExceptionInspection */
SetupWebPage::AddModule(
	__FILE__, // Path to the current file, all other file names are relative to the directory containing this file
	'itop-core-update/3.1.0',
	[
		// Identification
		//
		'label' => 'iTop Core Update',
		'category' => 'business',

		// Setup
		//
		'dependencies' => [
            'itop-files-information/2.7.0',
            'combodo-db-tools/2.7.0',
		],
		'mandatory' => false,
		'visible' => true,

		// Components
		//
		'datamodel' => [
			'src/Service/RunTimeEnvironmentCoreUpdater.php',
			'src/Service/CoreUpdater.php',
			'src/Controller/UpdateController.php',
			'src/Controller/AjaxController.php',
		],
		'webservice' => [],
		'data.struct' => [],
		'data.sample' => [],

		// Documentation
		//
		'doc.manual_setup' => '', // hyperlink to manual setup documentation, if any
		'doc.more_information' => '', // hyperlink to more information, if any

		// Default settings
		//
		'settings' => [],
	]
);
